@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2015, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2008-2016, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 #
 # License: MIT (see COPYING file)
@@ -28,6 +28,7 @@ def haralick(f,
             return_mean=False,
             return_mean_ptp=False,
             use_x_minus_y_variance=False,
+            distance=1
             ):
     '''
     feats = haralick(f, ignore_zeros=False, preserve_haralick_bug=False, compute_14th_feature=False)
@@ -37,6 +38,19 @@ def haralick(f,
     Computes the Haralick texture features for the four 2-D directions or
     thirteen 3-D directions (depending on the dimensions of `f`).
 
+    ``ignore_zeros`` can be used to have the function ignore any zero-valued
+    pixels (as background). If there are no-nonzero neighbour pairs in all
+    directions, an exception is raised. Note that this can happen even with
+    some non-zero pixels, e.g.::
+
+         0 0 0 0
+         0 1 0 0
+         0 1 0 0
+         0 0 0 0
+
+    would trigger an error when ``ignore_zeros=True`` as there are no
+    horizontal non-zero pairs!
+
     Notes
     -----
     Haralick's paper has a typo in one of the equations. This function
@@ -65,6 +79,8 @@ def haralick(f,
     ----------
     f : ndarray of integer type
         input image. 2-D and 3-D images are supported.
+    distance: int, optional (default=1)
+        The distance to consider while computing the cooccurence matrix.
     ignore_zeros : bool, optional
         Whether to ignore zero pixels (default: False).
 
@@ -112,7 +128,7 @@ def haralick(f,
     cmat = np.empty((fm1, fm1), np.int32)
     def all_cmatrices():
         for dir in range(nr_dirs):
-            cooccurence(f, dir, cmat, symmetric=True)
+            cooccurence(f, dir, cmat, symmetric=True, distance=distance)
             yield cmat
     return haralick_features(all_cmatrices(),
                         ignore_zeros=ignore_zeros,
@@ -219,7 +235,8 @@ def haralick_features(cmats,
             cmat[:,0] = 0
         T = cmat.sum()
         if not T:
-            continue
+            raise ValueError('mahotas.haralick_features: the input is empty. Cannot compute features!\n' +
+                                'This can happen if you are using `ignore_zeros`' )
         if not len(features):
             maxv = len(cmat)
             k = np.arange(maxv)
@@ -363,7 +380,7 @@ _3d_deltas = [
     (1, 1,-1),
     (1,-1,-1) ]
 
-def cooccurence(f, direction, output=None, symmetric=True):
+def cooccurence(f, direction, output=None, symmetric=True, distance=1):
     '''
     cooccurence_matrix = cooccurence(f, direction, output={new matrix})
 
@@ -380,6 +397,8 @@ def cooccurence(f, direction, output=None, symmetric=True):
         preallocated result.
     symmetric : boolean, optional
         whether return a symmetric matrix (default: False)
+    distance : integer, optional (default=1)
+        Distance to the central pixel to consider.
 
     Returns
     -------
@@ -402,13 +421,15 @@ def cooccurence(f, direction, output=None, symmetric=True):
         output.fill(0)
 
     if len(f.shape) == 2:
-        Bc = np.zeros((3, 3), f.dtype)
-        y,x = _2d_deltas[direction]
-        Bc[y+1,x+1] = 1
+        mask_size = 2 * distance + 1
+        Bc = np.zeros((mask_size, mask_size), f.dtype)
+        y, x = tuple(distance * i for i in _2d_deltas[direction])
+        Bc[y + distance, x + distance] = 1
     else:
-        Bc = np.zeros((3, 3, 3), f.dtype)
-        y,x,z = _3d_deltas[direction]
-        Bc[y+1,x+1,z+1] = 1
+        mask_size = 2 * distance + 1
+        Bc = np.zeros((mask_size, mask_size, mask_size), f.dtype)
+        y, x, z = tuple(distance * i for i in _3d_deltas[direction])
+        Bc[y + distance, x + distance, z + distance] = 1
     _texture.cooccurence(f, output, Bc, symmetric)
     return output
 
